'use client'

export type resizeImageProps = {
  file: File,
  options?: {
    maxWidth?: number,
    maxHeight?: number,
    quality?: number,
  }
};

export const resizeImage = async ({
  file,
  options = {},
}: resizeImageProps): Promise<File> => {
    const {
      maxWidth = 800,
      maxHeight = 800,
      quality = 0.8,
    } = options;
    return new Promise((resolve) => {
      const reader = new FileReader();
      reader.readAsDataURL(file);
      reader.onload = (event) => {
        const img = new Image();
        img.src = event.target?.result as string;
        img.onload = () => {
          let width = img.width;
          let height = img.height;
          if (width > height) {
            if (width > maxWidth) {
              height = Math.round((height * maxWidth / width));
              width = maxWidth;
            }
          } else if (height > maxHeight) {
            width = Math.round((width * maxHeight / height));
            height = maxHeight;
          }
          const canvas = document.createElement('canvas');
          canvas.width = width;
          canvas.height = height;
          const ctx = canvas.getContext('2d');
          ctx?.drawImage(img, 0, 0, width, height);
          canvas.toBlob(
            (blob) => {
              if (!blob) return;
              const resizedFile = new File([blob], file.name, {
                type: 'image/jpeg',
                lastModified: Date.now(),
              });
              resolve(resizedFile);
            },
            'image/jpeg',
            quality
          );
        };
      };
    });
};
